@@ -2,7 +2,7 @@
 #
 #  __init__.py
 """
-Helpful functions for Python 🐍 🛠️
+Helpful functions for Python 🐍 🛠️ .
 """
 #
 #  Copyright © 2018-2020 by Dominic Davis-Foster <dominic@davis-foster.co.uk>
@@ -27,7 +27,7 @@ __author__: str = "Dominic Davis-Foster"
 __copyright__: str = "2014-2020 Dominic Davis-Foster"
 
 __license__: str = "LGPLv3+"
-__version__: str = "0.9.1"
+__version__: str = "0.11.0"
 __email__: str = "dominic@davis-foster.co.uk"
 
 __docs = False
