@@ -2,7 +2,7 @@
 #
 #  typing.py
 """
-Common aliases for type hinting
+Common aliases for type hinting.
 
 **Data:**
 
@@ -15,8 +15,6 @@ Common aliases for type hinting
 	:data:`~.MethodWrapperType`, The type of *bound* methods of some built-in data types and base classes.
 	:data:`~.MethodDescriptorType`, The type of methods of some built-in data types.
 	:data:`~.ClassMethodDescriptorType`, The type of *unbound* class methods of some built-in data types.
-	:data:`~.String`, :class:`~typing.Protocol` for classes that implement ``__str__``.
-	:data:`~.HasHead`, :class:`typing.Protocol` for classes that have a ``head``.
 
 """
 #
@@ -41,14 +39,18 @@ Common aliases for type hinting
 # stdlib
 import os
 import pathlib
+import typing
 from decimal import Decimal
 from json import JSONDecoder, JSONEncoder
-from typing import TYPE_CHECKING, Any, Callable, Dict, List, Optional, Tuple, Type, Union
+from typing import Any, Callable, Dict, List, Optional, Tuple, Type, Union
 
 # 3rd party
 from typing_extensions import Protocol, runtime_checkable
 
-if TYPE_CHECKING:
+# this package
+import domdf_python_tools
+
+if typing.TYPE_CHECKING or domdf_python_tools.__docs:
 	# 3rd party
 	from pandas._typing import FrameOrSeries  # type: ignore
 
@@ -79,14 +81,11 @@ Type hint for numbers.
 
 
 def check_membership(obj: Any, type_: Union[Type, object]) -> bool:
-	"""
+	r"""
 	Check if the type of ``obj`` is one of the types in a :py:data:`typing.Union`, :class:`typing.Sequence` etc.
 
 	:param obj: The object to check the type of
-	:param type_: A :class:`~typing.Type` that has members, such as a List, Union or Sequence.
-
-	:return:
-	:rtype:
+	:param type\_: A :class:`~typing.Type` that has members, such as a List, Union or Sequence.
 	"""
 
 	return isinstance(obj, type_.__args__)  # type: ignore
@@ -166,7 +165,7 @@ class JsonLibrary(Protocol):
 WrapperDescriptorType = type(object.__init__)
 MethodWrapperType = type(object().__str__)
 MethodDescriptorType = type(str.join)
-ClassMethodDescriptorType = type(dict.__dict__['fromkeys'])
+ClassMethodDescriptorType = type(dict.__dict__["fromkeys"])
 
 
 @runtime_checkable
@@ -186,7 +185,7 @@ class String(Protocol):
 @runtime_checkable
 class HasHead(Protocol):
 	"""
-	:class:`typing.Protocol` for classes that have a ``head``.
+	:class:`typing.Protocol` for classes that have a ``head`` method.
 
 	This includes :class:`pandas.DataFrame` and :class:`pandas.Series`.
 
@@ -194,10 +193,18 @@ class HasHead(Protocol):
 	"""
 
 	def head(self: "FrameOrSeries", n: int = 5) -> "FrameOrSeries":
-		...  # pragma: no cover
+		"""
+		Return the first n rows.
+
+		:param n: Number of rows to select.
+
+		:return: The first n rows of the caller object.
+		"""
 
 	def to_string(self, *args, **kwargs) -> Optional[str]:
-		...  # pragma: no cover
+		"""
+		Render the object to a console-friendly tabular output.
+		"""
 
 
 # class SupportsLessThan(Protocol):
