@@ -42,7 +42,6 @@ from typing import Any, Dict, Iterable, List, Optional
 
 # 3rd party
 import importlib_resources
-from typing_extensions import Protocol
 
 # this package
 import domdf_python_tools
@@ -77,14 +76,14 @@ ASCII numbers.
 .. versionadded:: 0.7.0
 """
 
-greek_uppercase = 'ΑΒΓΔΕΖΗΘΙΚΛΜΝΞΟΠΡϴΣΤΥΦΧΨ'
+greek_uppercase = "ΑΒΓΔΕΖΗΘΙΚΛΜΝΞΟΠΡϴΣΤΥΦΧΨ"
 """
 Uppercase Greek letters.
 
 .. versionadded:: 0.7.0
 """
 
-greek_lowercase = 'αβγδεζηθικλμνξοπρςστυφχψω∂ϵϑϰϕϱϖ'
+greek_lowercase = "αβγδεζηθικλμνξοπρςστυφχψω∂ϵϑϰϕϱϖ"
 """
 Lowercase Greek letters.
 
@@ -105,7 +104,7 @@ def get_words_list(min_length: int = 0, max_length: int = -1) -> List[str]:
 	:return: The list of words meeting the above specifiers.
 
 	.. versionadded:: 0.4.5
-	"""
+	"""  # noqa D400
 
 	# this package
 	from domdf_python_tools.paths import PathPlus
@@ -136,7 +135,7 @@ def get_random_word(min_length: int = 0, max_length: int = -1) -> str:
 	:return: A random word meeting the above specifiers.
 
 	.. versionadded:: 0.4.5
-	"""
+	"""  # noqa D400
 
 	words_list = get_words_list(min_length=min_length, max_length=max_length)
 
@@ -249,7 +248,7 @@ def make_font(
 	:param greek_lowers: Optional iterable of lowercase Greek letters (𝛂-𝛡).
 
 	.. versionadded:: 0.7.0
-	"""
+	"""  # noqa D400
 
 	font = Font({
 			**{char: unichar
@@ -271,15 +270,15 @@ def make_font(
 
 
 #: Bold Serif letters (uppercase)
-SERIF_BOLD_UPPER = '𝐀𝐁𝐂𝐃𝐄𝐅𝐆𝐇𝐈𝐉𝐊𝐋𝐌𝐍𝐎𝐏𝐐𝐑𝐒𝐓𝐔𝐕𝐖𝐗𝐘𝐙'
+SERIF_BOLD_UPPER = "𝐀𝐁𝐂𝐃𝐄𝐅𝐆𝐇𝐈𝐉𝐊𝐋𝐌𝐍𝐎𝐏𝐐𝐑𝐒𝐓𝐔𝐕𝐖𝐗𝐘𝐙"
 #: Bold Serif letters (lowercase)
-SERIF_BOLD_LOWER = '𝐚𝐛𝐜𝐝𝐞𝐟𝐠𝐡𝐢𝐣𝐤𝐥𝐦𝐧𝐨𝐩𝐪𝐫𝐬𝐭𝐮𝐯𝐰𝐱𝐲𝐳'
+SERIF_BOLD_LOWER = "𝐚𝐛𝐜𝐝𝐞𝐟𝐠𝐡𝐢𝐣𝐤𝐥𝐦𝐧𝐨𝐩𝐪𝐫𝐬𝐭𝐮𝐯𝐰𝐱𝐲𝐳"
 #: Bold Serif digits
-SERIF_BOLD_DIGITS = '𝟎𝟏𝟐𝟑𝟒𝟓𝟔𝟕𝟖𝟗'
+SERIF_BOLD_DIGITS = "𝟎𝟏𝟐𝟑𝟒𝟓𝟔𝟕𝟖𝟗"
 #: Bold Serif Greek letters (uppercase)
-SERIF_BOLD_GREEK_UPPER = '𝚨𝚩𝚪𝚫𝚬𝚭𝚮𝚯𝚰𝚱𝚲𝚳𝚴𝚵𝚶𝚷𝚸𝚹𝚺𝚻𝚼𝚽𝚾𝚿𝛀𝛁'
+SERIF_BOLD_GREEK_UPPER = "𝚨𝚩𝚪𝚫𝚬𝚭𝚮𝚯𝚰𝚱𝚲𝚳𝚴𝚵𝚶𝚷𝚸𝚹𝚺𝚻𝚼𝚽𝚾𝚿𝛀𝛁"
 #: Bold Serif Greek letters (lowercase)
-SERIF_BOLD_GREEK_LOWER = '𝛂𝛃𝛄𝛅𝛆𝛇𝛈𝛉𝛊𝛋𝛌𝛍𝛎𝛏𝛐𝛑𝛒𝛓𝛔𝛕𝛖𝛗𝛘𝛙𝛚𝛛𝛜𝛝𝛞𝛟𝛠𝛡'
+SERIF_BOLD_GREEK_LOWER = "𝛂𝛃𝛄𝛅𝛆𝛇𝛈𝛉𝛊𝛋𝛌𝛍𝛎𝛏𝛐𝛑𝛒𝛓𝛔𝛕𝛖𝛗𝛘𝛙𝛚𝛛𝛜𝛝𝛞𝛟𝛠𝛡"
 
 SERIF_BOLD_LETTERS = make_font(
 		uppers=SERIF_BOLD_UPPER,
@@ -297,13 +296,13 @@ This font includes numbers and Greek letters.
 """
 
 #: Italic Serif letters (uppercase)
-SERIF_ITALIC_UPPER = '𝐴𝐵𝐶𝐷𝐸𝐹𝐺𝐻𝐼𝐽𝐾𝐿𝑀𝑁𝑂𝑃𝑄𝑅𝑆𝑇𝑈𝑉𝑊𝑋𝑌𝑍'
+SERIF_ITALIC_UPPER = "𝐴𝐵𝐶𝐷𝐸𝐹𝐺𝐻𝐼𝐽𝐾𝐿𝑀𝑁𝑂𝑃𝑄𝑅𝑆𝑇𝑈𝑉𝑊𝑋𝑌𝑍"
 #: Italic Serif letters (lowercase)
-SERIF_ITALIC_LOWER = '𝑎𝑏𝑐𝑑𝑒𝑓𝑔ℎ𝑖𝑗𝑘𝑙𝑚𝑛𝑜𝑝𝑞𝑟𝑠𝑡𝑢𝑣𝑤𝑥𝑦𝑧'
+SERIF_ITALIC_LOWER = "𝑎𝑏𝑐𝑑𝑒𝑓𝑔ℎ𝑖𝑗𝑘𝑙𝑚𝑛𝑜𝑝𝑞𝑟𝑠𝑡𝑢𝑣𝑤𝑥𝑦𝑧"
 #: Italic Serif Greek letters (uppercase)
-SERIF_ITALIC_GREEK_UPPER = '𝛢𝛣𝛤𝛥𝛦𝛧𝛨𝛩𝛪𝛫𝛬𝛭𝛮𝛯𝛰𝛱𝛲𝛳𝛴𝛵𝛶𝛷𝛸𝛹𝛺𝛻'
+SERIF_ITALIC_GREEK_UPPER = "𝛢𝛣𝛤𝛥𝛦𝛧𝛨𝛩𝛪𝛫𝛬𝛭𝛮𝛯𝛰𝛱𝛲𝛳𝛴𝛵𝛶𝛷𝛸𝛹𝛺𝛻"
 #: Italic Serif Greek letters (lowercase)
-SERIF_ITALIC_GREEK_LOWER = '𝛼𝛽𝛾𝛿𝜀𝜁𝜂𝜃𝜄𝜅𝜆𝜇𝜈𝜉𝜊𝜋𝜌𝜍𝜎𝜏𝜐𝜑𝜒𝜓𝜔𝜕𝜖𝜗𝜘𝜙𝜚𝜛'
+SERIF_ITALIC_GREEK_LOWER = "𝛼𝛽𝛾𝛿𝜀𝜁𝜂𝜃𝜄𝜅𝜆𝜇𝜈𝜉𝜊𝜋𝜌𝜍𝜎𝜏𝜐𝜑𝜒𝜓𝜔𝜕𝜖𝜗𝜘𝜙𝜚𝜛"
 
 SERIF_ITALIC_LETTERS = make_font(
 		uppers=SERIF_ITALIC_UPPER,
@@ -320,13 +319,13 @@ This font includes and Greek letters.
 """
 
 #: Bold and Italic Serif letters (uppercase)
-SERIF_BOLD_ITALIC_UPPER = '𝑨𝑩𝑪𝑫𝑬𝑭𝑮𝑯𝑰𝑱𝑲𝑳𝑴𝑵𝑶𝑷𝑸𝑹𝑺𝑻𝑼𝑽𝑾𝑿𝒀𝒁'
+SERIF_BOLD_ITALIC_UPPER = "𝑨𝑩𝑪𝑫𝑬𝑭𝑮𝑯𝑰𝑱𝑲𝑳𝑴𝑵𝑶𝑷𝑸𝑹𝑺𝑻𝑼𝑽𝑾𝑿𝒀𝒁"
 #: Bold and Italic Serif letters (lowercase)
-SERIF_BOLD_ITALIC_LOWER = '𝒂𝒃𝒄𝒅𝒆𝒇𝒈𝒉𝒊𝒋𝒌𝒍𝒎𝒏𝒐𝒑𝒒𝒓𝒔𝒕𝒖𝒗𝒘𝒙𝒚𝒛'
+SERIF_BOLD_ITALIC_LOWER = "𝒂𝒃𝒄𝒅𝒆𝒇𝒈𝒉𝒊𝒋𝒌𝒍𝒎𝒏𝒐𝒑𝒒𝒓𝒔𝒕𝒖𝒗𝒘𝒙𝒚𝒛"
 #: Bold and Italic Serif Greek letters (uppercase)
-SERIF_BOLD_ITALIC_GREEK_UPPER = '𝜜𝜝𝜞𝜟𝜠𝜡𝜢𝜣𝜤𝜥𝜦𝜧𝜨𝜩𝜪𝜫𝜬𝜭𝜮𝜯𝜰𝜱𝜲𝜳𝜴𝜵'
+SERIF_BOLD_ITALIC_GREEK_UPPER = "𝜜𝜝𝜞𝜟𝜠𝜡𝜢𝜣𝜤𝜥𝜦𝜧𝜨𝜩𝜪𝜫𝜬𝜭𝜮𝜯𝜰𝜱𝜲𝜳𝜴𝜵"
 #: Bold and Italic Serif Greek letters (lowercase)
-SERIF_BOLD_ITALIC_GREEK_LOWER = '𝜶𝜷𝜸𝜹𝜺𝜻𝜼𝜽𝜾𝜿𝝀𝝁𝝂𝝃𝝄𝝅𝝆𝝇𝝈𝝉𝝊𝝋𝝌𝝍𝝎𝝏𝝐𝝑𝝒𝝓𝝔𝝕'
+SERIF_BOLD_ITALIC_GREEK_LOWER = "𝜶𝜷𝜸𝜹𝜺𝜻𝜼𝜽𝜾𝜿𝝀𝝁𝝂𝝃𝝄𝝅𝝆𝝇𝝈𝝉𝝊𝝋𝝌𝝍𝝎𝝏𝝐𝝑𝝒𝝓𝝔𝝕"
 
 SERIF_BOLD_ITALIC_LETTERS = make_font(
 		uppers=SERIF_BOLD_ITALIC_UPPER,
@@ -343,11 +342,11 @@ This font includes Greek letters.
 """
 
 #: Normal Sans-Serif letters (uppercase)
-SANS_SERIF_UPPER = '𝖠𝖡𝖢𝖣𝖤𝖥𝖦𝖧𝖨𝖩𝖪𝖫𝖬𝖭𝖮𝖯𝖰𝖱𝖲𝖳𝖴𝖵𝖶𝖷𝖸𝖹'
+SANS_SERIF_UPPER = "𝖠𝖡𝖢𝖣𝖤𝖥𝖦𝖧𝖨𝖩𝖪𝖫𝖬𝖭𝖮𝖯𝖰𝖱𝖲𝖳𝖴𝖵𝖶𝖷𝖸𝖹"
 #: Normal Sans-Serif letters (lowercase)
-SANS_SERIF_LOWER = '𝖺𝖻𝖼𝖽𝖾𝖿𝗀𝗁𝗂𝗃𝗄𝗅𝗆𝗇𝗈𝗉𝗊𝗋𝗌𝗍𝗎𝗏𝗐𝗑𝗒𝗓'
+SANS_SERIF_LOWER = "𝖺𝖻𝖼𝖽𝖾𝖿𝗀𝗁𝗂𝗃𝗄𝗅𝗆𝗇𝗈𝗉𝗊𝗋𝗌𝗍𝗎𝗏𝗐𝗑𝗒𝗓"
 #: Normal Sans-Serif digits
-SANS_SERIF_DIGITS = '𝟢𝟣𝟤𝟥𝟦𝟧𝟨𝟩𝟪𝟫'
+SANS_SERIF_DIGITS = "𝟢𝟣𝟤𝟥𝟦𝟧𝟨𝟩𝟪𝟫"
 
 SANS_SERIF_LETTERS = make_font(
 		uppers=SANS_SERIF_UPPER,
@@ -363,11 +362,11 @@ This font includes numbers.
 """
 
 #: Bold Sans-Serif letters (uppercase)
-SANS_SERIF_BOLD_UPPER = '𝗔𝗕𝗖𝗗𝗘𝗙𝗚𝗛𝗜𝗝𝗞𝗟𝗠𝗡𝗢𝗣𝗤𝗥𝗦𝗧𝗨𝗩𝗪𝗫𝗬𝗭'
+SANS_SERIF_BOLD_UPPER = "𝗔𝗕𝗖𝗗𝗘𝗙𝗚𝗛𝗜𝗝𝗞𝗟𝗠𝗡𝗢𝗣𝗤𝗥𝗦𝗧𝗨𝗩𝗪𝗫𝗬𝗭"
 #: Bold Sans-Serif letters (lowercase)
-SANS_SERIF_BOLD_LOWER = '𝗮𝗯𝗰𝗱𝗲𝗳𝗴𝗵𝗶𝗷𝗸𝗹𝗺𝗻𝗼𝗽𝗾𝗿𝘀𝘁𝘂𝘃𝘄𝘅𝘆𝘇'
+SANS_SERIF_BOLD_LOWER = "𝗮𝗯𝗰𝗱𝗲𝗳𝗴𝗵𝗶𝗷𝗸𝗹𝗺𝗻𝗼𝗽𝗾𝗿𝘀𝘁𝘂𝘃𝘄𝘅𝘆𝘇"
 #: Bold Sans-Serif digits
-SANS_SERIF_BOLD_DIGITS = '𝟬𝟭𝟮𝟯𝟰𝟱𝟲𝟳𝟴𝟵'
+SANS_SERIF_BOLD_DIGITS = "𝟬𝟭𝟮𝟯𝟰𝟱𝟲𝟳𝟴𝟵"
 
 SANS_SERIF_BOLD_LETTERS = make_font(
 		uppers=SANS_SERIF_BOLD_UPPER,
@@ -383,9 +382,9 @@ This font includes numbers.
 """
 
 #: Italic Sans-Serif letters (uppercase)
-SANS_SERIF_ITALIC_UPPER = '𝘈𝘉𝘊𝘋𝘌𝘍𝘎𝘏𝘐𝘑𝘒𝘓𝘔𝘕𝘖𝘗𝘘𝘙𝘚𝘛𝘜𝘝𝘞𝘟𝘠𝘡'
+SANS_SERIF_ITALIC_UPPER = "𝘈𝘉𝘊𝘋𝘌𝘍𝘎𝘏𝘐𝘑𝘒𝘓𝘔𝘕𝘖𝘗𝘘𝘙𝘚𝘛𝘜𝘝𝘞𝘟𝘠𝘡"
 #: Italic Sans-Serif letters (lowercase)
-SANS_SERIF_ITALIC_LOWER = '𝘢𝘣𝘤𝘥𝘦𝘧𝘨𝘩𝘪𝘫𝘬𝘭𝘮𝘯𝘰𝘱𝘲𝘳𝘴𝘵𝘶𝘷𝘸𝘹𝘺𝘻'
+SANS_SERIF_ITALIC_LOWER = "𝘢𝘣𝘤𝘥𝘦𝘧𝘨𝘩𝘪𝘫𝘬𝘭𝘮𝘯𝘰𝘱𝘲𝘳𝘴𝘵𝘶𝘷𝘸𝘹𝘺𝘻"
 
 SANS_SERIF_ITALIC_LETTERS = make_font(
 		uppers=SANS_SERIF_ITALIC_UPPER,
@@ -398,13 +397,13 @@ Italic Sans-Serif :class:`domdf_python_tools.words.Font`
 """
 
 #: Bold and Italic Sans-Serif letters (uppercase)
-SANS_SERIF_BOLD_ITALIC_UPPER = '𝘼𝘽𝘾𝘿𝙀𝙁𝙂𝙃𝙄𝙅𝙆𝙇𝙈𝙉𝙊𝙋𝙌𝙍𝙎𝙏𝙐𝙑𝙒𝙓𝙔𝙕'
+SANS_SERIF_BOLD_ITALIC_UPPER = "𝘼𝘽𝘾𝘿𝙀𝙁𝙂𝙃𝙄𝙅𝙆𝙇𝙈𝙉𝙊𝙋𝙌𝙍𝙎𝙏𝙐𝙑𝙒𝙓𝙔𝙕"
 #: Bold and Italic Sans-Serif letters (lowercase)
-SANS_SERIF_BOLD_ITALIC_LOWER = '𝙖𝙗𝙘𝙙𝙚𝙛𝙜𝙝𝙞𝙟𝙠𝙡𝙢𝙣𝙤𝙥𝙦𝙧𝙨𝙩𝙪𝙫𝙬𝙭𝙮𝙯'
+SANS_SERIF_BOLD_ITALIC_LOWER = "𝙖𝙗𝙘𝙙𝙚𝙛𝙜𝙝𝙞𝙟𝙠𝙡𝙢𝙣𝙤𝙥𝙦𝙧𝙨𝙩𝙪𝙫𝙬𝙭𝙮𝙯"
 #: Bold and Italic Sans-Serif letters (uppercase)
-SANS_SERIF_BOLD_ITALIC_GREEK_UPPER = '𝞐𝞑𝞒𝞓𝞔𝞕𝞖𝞗𝞘𝞙𝞚𝞛𝞜𝞝𝞞𝞟𝞠𝞡𝞢𝞣𝞤𝞥𝞦𝞧𝞨𝞩'
+SANS_SERIF_BOLD_ITALIC_GREEK_UPPER = "𝞐𝞑𝞒𝞓𝞔𝞕𝞖𝞗𝞘𝞙𝞚𝞛𝞜𝞝𝞞𝞟𝞠𝞡𝞢𝞣𝞤𝞥𝞦𝞧𝞨𝞩"
 #: Bold and Italic Sans-Serif letters (lowercase)
-SANS_SERIF_BOLD_ITALIC_GREEK_LOWER = '𝞪𝞫𝞬𝞭𝞮𝞯𝞰𝞱𝞲𝞳𝞴𝞵𝞶𝞷𝞸𝞹𝞺𝞻𝞼𝞽𝞾𝞿𝟀𝟁𝟂𝟃𝟄𝟅𝟆𝟇𝟈𝟉'
+SANS_SERIF_BOLD_ITALIC_GREEK_LOWER = "𝞪𝞫𝞬𝞭𝞮𝞯𝞰𝞱𝞲𝞳𝞴𝞵𝞶𝞷𝞸𝞹𝞺𝞻𝞼𝞽𝞾𝞿𝟀𝟁𝟂𝟃𝟄𝟅𝟆𝟇𝟈𝟉"
 
 SANS_SERIF_BOLD_ITALIC_LETTERS = make_font(
 		uppers=SANS_SERIF_BOLD_ITALIC_UPPER,
@@ -421,7 +420,7 @@ This font includes Greek letters.
 """
 
 #: Script letters (uppercase)
-SCRIPT_UPPER = '𝓐𝓑𝓒𝓓𝓔𝓕𝓖𝓗𝓘𝓙𝓚𝓛𝓜𝓝𝓞𝓟𝓠𝓡𝓢𝓣𝓤𝓥𝓦𝓧𝓨𝓩'
+SCRIPT_UPPER = "𝓐𝓑𝓒𝓓𝓔𝓕𝓖𝓗𝓘𝓙𝓚𝓛𝓜𝓝𝓞𝓟𝓠𝓡𝓢𝓣𝓤𝓥𝓦𝓧𝓨𝓩"
 #: Script letters (lowercase)
 SCRIPT_LOWER = '𝓪𝓫𝓬𝓭𝓮𝓯𝓰𝓱𝓲𝓳𝓴𝓵𝓶𝓷𝓸𝓹𝓺𝓻𝓼𝓽𝓾𝓿𝔀𝔁𝔂𝔃'
 
@@ -433,9 +432,9 @@ Script :class:`domdf_python_tools.words.Font`.
 """
 
 #: Fraktur letters (uppercase)
-FRAKTUR_UPPER = '𝕬𝕭𝕮𝕯𝕰𝕱𝕲𝕳𝕴𝕵𝕶𝕷𝕸𝕹𝕺𝕻𝕼𝕽𝕾𝕿𝖀𝖁𝖂𝖃𝖄𝖅'
+FRAKTUR_UPPER = "𝕬𝕭𝕮𝕯𝕰𝕱𝕲𝕳𝕴𝕵𝕶𝕷𝕸𝕹𝕺𝕻𝕼𝕽𝕾𝕿𝖀𝖁𝖂𝖃𝖄𝖅"
 #: Fraktur letters (lowercase)
-FRAKTUR_LOWER = '𝖆𝖇𝖈𝖉𝖊𝖋𝖌𝖍𝖎𝖏𝖐𝖑𝖒𝖓𝖔𝖕𝖖𝖗𝖘𝖙𝖚𝖛𝖜𝖝𝖞𝖟'
+FRAKTUR_LOWER = "𝖆𝖇𝖈𝖉𝖊𝖋𝖌𝖍𝖎𝖏𝖐𝖑𝖒𝖓𝖔𝖕𝖖𝖗𝖘𝖙𝖚𝖛𝖜𝖝𝖞𝖟"
 
 FRAKTUR_LETTERS = make_font(FRAKTUR_UPPER, FRAKTUR_LOWER)
 """
@@ -445,11 +444,11 @@ Fraktur :class:`domdf_python_tools.words.Font`.
 """
 
 #: Monospace letters (uppercase)
-MONOSPACE_UPPER = '𝙰𝙱𝙲𝙳𝙴𝙵𝙶𝙷𝙸𝙹𝙺𝙻𝙼𝙽𝙾𝙿𝚀𝚁𝚂𝚃𝚄𝚅𝚆𝚇𝚈𝚉'
+MONOSPACE_UPPER = "𝙰𝙱𝙲𝙳𝙴𝙵𝙶𝙷𝙸𝙹𝙺𝙻𝙼𝙽𝙾𝙿𝚀𝚁𝚂𝚃𝚄𝚅𝚆𝚇𝚈𝚉"
 #: Monospace letters (lowercase)
-MONOSPACE_LOWER = '𝚊𝚋𝚌𝚍𝚎𝚏𝚐𝚑𝚒𝚓𝚔𝚕𝚖𝚗𝚘𝚙𝚚𝚛𝚜𝚝𝚞𝚟𝚠𝚡𝚢𝚣'
+MONOSPACE_LOWER = "𝚊𝚋𝚌𝚍𝚎𝚏𝚐𝚑𝚒𝚓𝚔𝚕𝚖𝚗𝚘𝚙𝚚𝚛𝚜𝚝𝚞𝚟𝚠𝚡𝚢𝚣"
 #: Monospace digits
-MONOSPACE_DIGITS = '𝟶𝟷𝟸𝟹𝟺𝟻𝟼𝟽𝟾𝟿'
+MONOSPACE_DIGITS = "𝟶𝟷𝟸𝟹𝟺𝟻𝟼𝟽𝟾𝟿"
 
 MONOSPACE_LETTERS = make_font(MONOSPACE_UPPER, MONOSPACE_LOWER, MONOSPACE_DIGITS)
 """
@@ -461,11 +460,11 @@ This font includes numbers.
 """
 
 #: Doublestruck letters (uppercase)
-DOUBLESTRUCK_UPPER = '𝔸𝔹ℂ𝔻𝔼𝔽𝔾ℍ𝕀𝕁𝕂𝕃𝕄ℕ𝕆ℙℚℝ𝕊𝕋𝕌𝕍𝕎𝕏𝕐ℤ'
+DOUBLESTRUCK_UPPER = "𝔸𝔹ℂ𝔻𝔼𝔽𝔾ℍ𝕀𝕁𝕂𝕃𝕄ℕ𝕆ℙℚℝ𝕊𝕋𝕌𝕍𝕎𝕏𝕐ℤ"
 #: Doublestruck letters (lowercase)
-DOUBLESTRUCK_LOWER = '𝕒𝕓𝕔𝕕𝕖𝕗𝕘𝕙𝕚𝕛𝕜𝕝𝕞𝕟𝕠𝕡𝕢𝕣𝕤𝕥𝕦𝕧𝕨𝕩𝕪𝕫'
+DOUBLESTRUCK_LOWER = "𝕒𝕓𝕔𝕕𝕖𝕗𝕘𝕙𝕚𝕛𝕜𝕝𝕞𝕟𝕠𝕡𝕢𝕣𝕤𝕥𝕦𝕧𝕨𝕩𝕪𝕫"
 #: Doublestruck digits
-DOUBLESTRUCK_DIGITS = '𝟘𝟙𝟚𝟛𝟜𝟝𝟞𝟟𝟠𝟡'
+DOUBLESTRUCK_DIGITS = "𝟘𝟙𝟚𝟛𝟜𝟝𝟞𝟟𝟠𝟡"
 
 DOUBLESTRUCK_LETTERS = make_font(DOUBLESTRUCK_UPPER, DOUBLESTRUCK_LOWER, DOUBLESTRUCK_DIGITS)
 """
@@ -479,7 +478,7 @@ This font includes numbers.
 
 def as_text(value: Any) -> str:
 	"""
-	Convert the given value to a string. ``None`` is converted to ``''``.
+	Convert the given value to a string. :py:obj:`None` is converted to ``''``.
 
 	:param value: The value to convert to a string.
 
@@ -494,7 +493,13 @@ def as_text(value: Any) -> str:
 	return str(value)
 
 
-def word_join(iterable: Iterable[str], use_repr: bool = False, oxford: bool = False) -> str:
+def word_join(
+		iterable: Iterable[str],
+		use_repr: bool = False,
+		oxford: bool = False,
+		delimiter: str = ",",
+		connective: str = "and",
+		) -> str:
 	"""
 	Join the given list of strings in a natural manner, with 'and' to join the last two elements.
 
@@ -502,8 +507,17 @@ def word_join(iterable: Iterable[str], use_repr: bool = False, oxford: bool = Fa
 	:param use_repr: Whether to join the ``repr`` of each object.
 	:param oxford: Whether to use an oxford comma when joining the last two elements.
 		Always :py:obj:`False` if there are fewer than three elements.
+	:param delimiter: A single character to use between the words.
+	:param connective: The connective to join the final two words with.
+
+	.. versionchanged:: 0.11.0
+
+		Added ``delimiter`` and ``connective`` arguments.
+
 	"""
 
+	delimiter = f"{delimiter} "
+
 	if use_repr:
 		words = [repr(w) for w in iterable]
 	else:
@@ -517,6 +531,6 @@ def word_join(iterable: Iterable[str], use_repr: bool = False, oxford: bool = Fa
 		return " and ".join(words)
 	else:
 		if oxford:
-			return ", ".join(words[:-1]) + f", and {words[-1]}"
+			return delimiter.join(words[:-1]) + f"{delimiter}{connective} {words[-1]}"
 		else:
-			return ", ".join(words[:-1]) + f" and {words[-1]}"
+			return delimiter.join(words[:-1]) + f" {connective} {words[-1]}"
